@@ -94,6 +94,7 @@ if PY2:
     text_type = __builtin__.unicode
     getcwdu = os.getcwdu
     map = itertools.imap
+    FileNotFoundError = OSError
 
 
 @contextlib.contextmanager
@@ -122,8 +123,8 @@ U_NL_END = re.compile(r'(?:{0})$'.format(U_NEWLINE.pattern))
 
 
 try:
-    import pkg_resources
-    __version__ = pkg_resources.require('path.py')[0].version
+    import importlib_metadata
+    __version__ = importlib_metadata.version('path.py')
 except Exception:
     __version__ = 'unknown'
 
@@ -923,15 +924,9 @@ class Path(text_type):
                 translated to ``'\n'``.  If ``False``, newline characters are
                 stripped off.  Default is ``True``.
 
-        This uses ``'U'`` mode.
-
         .. seealso:: :meth:`text`
         """
-        if encoding is None and retain:
-            with self.open('U') as f:
-                return f.readlines()
-        else:
-            return self.text(encoding, errors).splitlines(retain)
+        return self.text(encoding, errors).splitlines(retain)
 
     def write_lines(self, lines, encoding=None, errors='strict',
                     linesep=os.linesep, append=False):
@@ -1321,9 +1316,8 @@ class Path(text_type):
         file does not exist. """
         try:
             self.unlink()
-        except OSError:
-            _, e, _ = sys.exc_info()
-            if e.errno != errno.ENOENT:
+        except FileNotFoundError as exc:
+            if PY2 and exc.errno != errno.ENOENT:
                 raise
         return self
 
